@@ -14,12 +14,14 @@ class bcolors:
 
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
 def filechecker(FILENAME):
-    if os.path.isfile(FILENAME):
-        print(bcolors.OKGREEN + "%s file is created" % FILENAME + bcolors.ENDC)
-    else: 
-        print(bcolors.FAIL + "%s file is not created, please try again" % FILENAME + bcolors.ENDC)
-    time.sleep(0.5)
-
+    try:
+        if os.path.isfile(FILENAME):
+            print(bcolors.OKGREEN + "%s file is created" % FILENAME + bcolors.ENDC)
+        else: 
+            print(bcolors.FAIL + "%s file is not created, please try again" % FILENAME + bcolors.ENDC)
+        time.sleep(0.5)
+    except FileNotFoundError:
+        print(bcolors.FAIL +  FILENAME + " is not created"+ bcolors.ENDC)
 
 
 def folderchecker(FOLDERNAME):
